@@ -6,7 +6,7 @@ class BaseError(Exception):
         super().__init__()
 
     def __str__(self):
-        return f"{self.val} --> {self.message}"
+        return "{} --> {}".format(self.val, self.message)
 
 
 class LanguageNotSupportedException(BaseError):
