@@ -3,6 +3,7 @@
 """Tests for `deep_translator` package."""
 
 import pytest
+from deep_translator import exceptions, GoogleTranslator
 
 
 @pytest.fixture
@@ -11,12 +12,13 @@ def response():
 
     See more at: http://doc.pytest.org/en/latest/fixture.html
     """
-    pass
-    # with pytest.raises(LanguageNotSupportedException):
-    #     GoogleTranslator(source="", target="")
-    #
-    # with pytest.raises(LanguageNotSupportedException):
-    #     GoogleTranslator(source="auto", target="nothing")
+    translator = GoogleTranslator(target='en')
+    assert translator.translate(payload='좋은') == "good"
+    with pytest.raises(exceptions.LanguageNotSupportedException):
+        GoogleTranslator(source="", target="")
+
+    with pytest.raises(exceptions.LanguageNotSupportedException):
+        GoogleTranslator(source="auto", target="nothing")
 
 
 def test_content(response):
